.. Lithoxyl documentation master file, created on Sun Apr 12 16:44:20 2015.


Lithoxyl
========

Lithoxyl is a next-generation instrumentation toolkit for Python
applications, offering a semantic, action-oriented approach to logging
and metrics collection. Lithoxyl integration is compact and
performant, minimizing impact on codebase readability and system
performance.

Sections
--------

.. toctree::
   :maxdepth: 2

   overview
   action
   logger
   sinks
   sensible
   logging_tradition
   faq
   glossary
